===============================
brick
===============================

OpenStack Cinder brick library for managing local volume attaches


Features
--------

* Discovery of volumes being attached to a host for many transport protocols.
* Removal of volumes from a host.



For any other imformation, refer to the parent project, Cinder:
  https://github.com/openstack/cinder

* License: Apache License, Version 2.0
* Source: http://git.openstack.org/cgit/openstack/os-brick
* Bugs: http://bugs.launchpad.net/os-brick
